==> ICA-1.5.tar.gz: ICA-1.5/src/RETAG/Replace/types.h <==
/* CONTENTS
   Owner:       Copyright 1992 The Ohio State University,
                Integrated Chameleon Architecture
   Module:      $RCSfile: types.h,v $
   Purpose:     

   Programmer:  Conleth O'Connell
   Reviewer:    
   Revision:    $Revision: 1.7 $
   Date:        $Date: 92/03/16 15:02:39 $

   HISTORY
   $Log:	types.h,v $
 * Revision 1.7  92/03/16  15:02:39  ware
 * Make titles consistent.
 * 
 * Revision 1.6  1992/03/10  19:40:03  cso
 * Added log header
 *
*/

typedef enum TagCodeType
{
   ExBeg  = 1,
   ExEnd  = 2,
   ImBeg  = 3,
   ImEnd  = 4,
   Symbol = 5,
   ProcIn = 6,
   Begin  = 7,
   EndT   = 8,
   Comma  = 9
} TagCode;

typedef enum ConCodeType
{
   Start  = 1,
   Stop   = 2,
   In     = 3,
   Nest   = 4,
   Nope   = 5
} ConCode;

typedef struct LexTableType
{
   Boolean
      amb;
   ConCode
      ccode;
   String
      regexp,
      context;
} LexTable;

typedef struct YaccTableType
{
   Boolean
      segflag,
      root;
   int
      endndx,
      lexndx;
   String
      tag;
   TagCode
      tcode;
} YaccTable;



typedef struct TagspecType
{
    String
       context,  /* context clause */
       regexp,   /* regular expression */
       tag;      /* tag name */
    TagCode
       tcode;    /* The type of tag */
    Widget
       conw,     /* Context widget */
       rexw,     /* Reg Exp widget */
       tagw,     /* Tag     widget */
       togw;     /* Toggle  widget */
    struct TagspecType
       *next;    /* pointer to next tag specification*/
} Tagspec;       /* Tag information */

typedef struct ContextListType
{
    String
       cond;     /* context condition */
    struct ContextListType
       *next;    /* Pointer to next condition */
} ContextList;   /* List of context conditions */

typedef struct RTTstructType
{
    String
       data,     /* data      characters */
       tags,     /* tag       characters */
       ambg,     /* ambiguous characters */
       root;     /* the root tag */
    Tagspec
       *symptr,  /* symbol tag info */
       *pinptr,  /* processing instruction info */
       *sepptr,  /* separator tag info */
       *impptr,  /* implicit tag info */
       *expptr;  /* explicit tag info */
    ContextList
       *conptr;  /* Context condition info */
} RTTspec;       /* Replace Tag Tool specification */

==> ICA-1.6.tar.gz: ICA-1.6/src/RETAG/Replace/types.h <==
/* CONTENTS
   Owner:       Copyright 1992 The Ohio State University,
                Integrated Chameleon Architecture
   Module:      types.h,v
   Purpose:     

   Programmer:  Conleth O'Connell
   Reviewer:    
   Revision:    1.8
   Date:        1993/04/19 17:12:36

   HISTORY
   types.h,v
 * Revision 1.8  1993/04/19  17:12:36  ware
 * Merged John Boyds changes.
 *
 * Revision 1.8  92/10/12    applegate
 * Added a flag to the TagspecType struct to indicate when a tag 
 * has been imported.
 *
 * Revision 1.7  92/03/16  15:02:39  ware
 * Make titles consistent.
 * 
 * Revision 1.6  1992/03/10  19:40:03  cso
 * Added log header
 *
*/

typedef enum TagCodeType
{
   ExBeg  = 1,
   ExEnd  = 2,
   ImBeg  = 3,
   ImEnd  = 4,
   Symbol = 5,
   ProcIn = 6,
   Begin  = 7,
   EndT   = 8,
   Comma  = 9
} TagCode;

typedef enum ConCodeType
{
   Start  = 1,
   Stop   = 2,
   In     = 3,
   Nest   = 4,
   Nope   = 5
} ConCode;

typedef struct LexTableType
{
   Boolean
      amb;
   ConCode
      ccode;
   String
      regexp,
      context;
} LexTable;

typedef struct YaccTableType
{
   Boolean
      segflag,
      root;
   int
      endndx,
      lexndx;
   String
      tag;
   TagCode
      tcode;
} YaccTable;



typedef struct TagspecType
{
    String
       context,  /* context clause */
       regexp,   /* regular expression */
       tag,      /* tag name */
       import;   /* Flag indicating whether tag was imported */
    TagCode
       tcode;    /* The type of tag */
    Widget
       conw,     /* Context widget */
       rexw,     /* Reg Exp widget */
       tagw,     /* Tag     widget */
       togw;     /* Toggle  widget */
    struct TagspecType
       *next;    /* pointer to next tag specification*/
} Tagspec;       /* Tag information */

typedef struct ContextListType
{
    String
       cond;     /* context condition */
    struct ContextListType
       *next;    /* Pointer to next condition */
} ContextList;   /* List of context conditions */

typedef struct RTTstructType
{
    String
       data,     /* data      characters */
       tags,     /* tag       characters */
       ambg,     /* ambiguous characters */
       root;     /* the root tag */
    Tagspec
       *symptr,  /* symbol tag info */
       *pinptr,  /* processing instruction info */
       *sepptr,  /* separator tag info */
       *impptr,  /* implicit tag info */
       *expptr;  /* explicit tag info */
    ContextList
       *conptr;  /* Context condition info */
} RTTspec;       /* Replace Tag Tool specification */
